Live Data
_________

.. notebook:: holoviews ../../examples/getting_started/5-Live_Data.ipynb
    :skip_output: When run live, this cell's output should match the behavior of the GIF below
    :offset: 1
